@@ -4,8 +4,9 @@ import io
 import base64
 import requests
 from configparser import ConfigParser
-from os.path import join, dirname, isfile
+from os.path import join, dirname, isfile, isdir
 
+import uuid
 import torch
 from torch.utils import model_zoo
 
@@ -131,8 +132,9 @@ def delete(url, **kwargs):
     return handle_response(res)
 
 
-def model_to_io_file(model, filename='model.pth'):
+def model_to_io_file(model):
     """Load model as BytesIO (creates file in RAM)"""
+    filename = f'{uuid.uuid4()}.pth'
     model_io = io.BytesIO()
     torch.save(model, model_io)
     return filename, model_io.getvalue()
@@ -245,7 +247,14 @@ def load_model_from_url(model_url):
     :param str model_url: Model .pt or .pth URL
     :return torch.Module: Model loaded
     """
-    return model_zoo.load_url(model_url, progress=False)
+    model_dir = join(TEMP_DIR, f'downloaded_models')
+    if not isdir(model_dir):
+        os.makedirs(model_dir, exist_ok=True)
+    cached_models = [join(model_dir, f) for f in os.listdir(model_dir) if f.endswith('pth')]
+    for m in cached_models:
+        if isfile(m):
+            os.remove(m)
+    return model_zoo.load_url(model_url, progress=False, model_dir=model_dir)
 
 
 def load_base_model(job):
